# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/workspace/project.proto\x12\x10\x65olymp.workspace\x1a!eolymp/annotations/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x03\n\x07Project\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x38\n\nvisibility\x18\x04 \x01(\x0e\x32$.eolymp.workspace.Project.Visibility\x12\x11\n\tauthor_id\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x06target\x18\n \x01(\x0b\x32 .eolymp.workspace.Project.Target\x12\x12\n\ntarget_ern\x18\x0b \x01(\t\x12\x0e\n\x06labels\x18\x64 \x03(\t\x1a.\n\x06Target\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"/\n\nVisibility\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\n\n\x06PUBLIC\x10\x02:\x0f\xb2\xe3\n\x0b\xba\xe3\n\x07projectB5Z3github.com/eolymp/go-sdk/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/workspace;workspace'
  _PROJECT._options = None
  _PROJECT._serialized_options = b'\262\343\n\013\272\343\n\007project'
  _PROJECT._serialized_start=121
  _PROJECT._serialized_end=560
  _PROJECT_TARGET._serialized_start=448
  _PROJECT_TARGET._serialized_end=494
  _PROJECT_VISIBILITY._serialized_start=496
  _PROJECT_VISIBILITY._serialized_end=543
# @@protoc_insertion_point(module_scope)



from eolymp.ranker import format_pb2 as _format_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scoreboard(_message.Message):
    __slots__ = ["default_sort_column", "default_sort_order", "format", "historical", "id", "key", "name", "timeline"]
    class FetchingMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Column(_message.Message):
        __slots__ = ["community_attribute_key", "community_attribute_type", "filterable", "id", "index", "judge_contest_id", "judge_problem_id", "key", "name", "parent_id", "short_name", "sortable", "type", "visible"]
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ATTRIBUTE: Scoreboard.Column.Type
        COMMUNITY_ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
        COMMUNITY_ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
        CONTEST: Scoreboard.Column.Type
        FILTERABLE_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        JUDGE_CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
        JUDGE_PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        NAME: Scoreboard.Column.Type
        NAME_FIELD_NUMBER: _ClassVar[int]
        NONE: Scoreboard.Column.Type
        PARENT_ID_FIELD_NUMBER: _ClassVar[int]
        PROBLEM: Scoreboard.Column.Type
        SHORT_NAME_FIELD_NUMBER: _ClassVar[int]
        SORTABLE_FIELD_NUMBER: _ClassVar[int]
        TOTAL: Scoreboard.Column.Type
        TYPE_FIELD_NUMBER: _ClassVar[int]
        VISIBLE_FIELD_NUMBER: _ClassVar[int]
        community_attribute_key: str
        community_attribute_type: str
        filterable: bool
        id: str
        index: int
        judge_contest_id: str
        judge_problem_id: str
        key: str
        name: str
        parent_id: str
        short_name: str
        sortable: bool
        type: Scoreboard.Column.Type
        visible: bool
        def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., short_name: _Optional[str] = ..., type: _Optional[_Union[Scoreboard.Column.Type, str]] = ..., index: _Optional[int] = ..., visible: bool = ..., filterable: bool = ..., sortable: bool = ..., judge_contest_id: _Optional[str] = ..., judge_problem_id: _Optional[str] = ..., community_attribute_key: _Optional[str] = ..., community_attribute_type: _Optional[str] = ...) -> None: ...
    class Row(_message.Message):
        __slots__ = ["ghost", "id", "member_id", "name", "out_of_competition", "penalty", "rank", "rank_lower", "score", "values"]
        class Value(_message.Message):
            __slots__ = ["attempts", "column_id", "id", "penalty", "percentage", "score", "solved_in", "timeline_end_offset", "timeline_start_offset", "value_number", "value_string"]
            ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
            COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
            ID_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
            SCORE_FIELD_NUMBER: _ClassVar[int]
            SOLVED_IN_FIELD_NUMBER: _ClassVar[int]
            TIMELINE_END_OFFSET_FIELD_NUMBER: _ClassVar[int]
            TIMELINE_START_OFFSET_FIELD_NUMBER: _ClassVar[int]
            VALUE_NUMBER_FIELD_NUMBER: _ClassVar[int]
            VALUE_STRING_FIELD_NUMBER: _ClassVar[int]
            attempts: int
            column_id: str
            id: str
            penalty: float
            percentage: float
            score: float
            solved_in: int
            timeline_end_offset: int
            timeline_start_offset: int
            value_number: int
            value_string: str
            def __init__(self, id: _Optional[str] = ..., column_id: _Optional[str] = ..., timeline_start_offset: _Optional[int] = ..., timeline_end_offset: _Optional[int] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., percentage: _Optional[float] = ..., attempts: _Optional[int] = ..., solved_in: _Optional[int] = ..., value_string: _Optional[str] = ..., value_number: _Optional[int] = ...) -> None: ...
        GHOST_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OUT_OF_COMPETITION_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        ghost: bool
        id: str
        member_id: str
        name: str
        out_of_competition: bool
        penalty: float
        rank: int
        rank_lower: int
        score: float
        values: _containers.RepeatedCompositeFieldContainer[Scoreboard.Row.Value]
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., member_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., ghost: bool = ..., out_of_competition: bool = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., values: _Optional[_Iterable[_Union[Scoreboard.Row.Value, _Mapping]]] = ...) -> None: ...
    class Segment(_message.Message):
        __slots__ = ["end_offset", "freeze_time", "start_offset", "starts_at"]
        END_OFFSET_FIELD_NUMBER: _ClassVar[int]
        FREEZE_TIME_FIELD_NUMBER: _ClassVar[int]
        STARTS_AT_FIELD_NUMBER: _ClassVar[int]
        START_OFFSET_FIELD_NUMBER: _ClassVar[int]
        end_offset: int
        freeze_time: int
        start_offset: int
        starts_at: _timestamp_pb2.Timestamp
        def __init__(self, starts_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., start_offset: _Optional[int] = ..., end_offset: _Optional[int] = ..., freeze_time: _Optional[int] = ...) -> None: ...
    class Timeline(_message.Message):
        __slots__ = ["duration", "freeze_in", "frozen", "position", "segments", "unfreeze_in"]
        DURATION_FIELD_NUMBER: _ClassVar[int]
        FREEZE_IN_FIELD_NUMBER: _ClassVar[int]
        FROZEN_FIELD_NUMBER: _ClassVar[int]
        POSITION_FIELD_NUMBER: _ClassVar[int]
        SEGMENTS_FIELD_NUMBER: _ClassVar[int]
        UNFREEZE_IN_FIELD_NUMBER: _ClassVar[int]
        duration: int
        freeze_in: int
        frozen: bool
        position: int
        segments: _containers.RepeatedCompositeFieldContainer[Scoreboard.Segment]
        unfreeze_in: int
        def __init__(self, position: _Optional[int] = ..., duration: _Optional[int] = ..., frozen: bool = ..., freeze_in: _Optional[int] = ..., unfreeze_in: _Optional[int] = ..., segments: _Optional[_Iterable[_Union[Scoreboard.Segment, _Mapping]]] = ...) -> None: ...
    ACTUAL: Scoreboard.FetchingMode
    DEFAULT_SORT_COLUMN_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_SORT_ORDER_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    FROZEN: Scoreboard.FetchingMode
    HISTORICAL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    LATEST: Scoreboard.FetchingMode
    NAME_FIELD_NUMBER: _ClassVar[int]
    PUNCTUAL: Scoreboard.FetchingMode
    TIMELINE_FIELD_NUMBER: _ClassVar[int]
    default_sort_column: str
    default_sort_order: _direction_pb2.Direction
    format: _format_pb2.Format
    historical: bool
    id: str
    key: str
    name: str
    timeline: Scoreboard.Timeline
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., historical: bool = ..., timeline: _Optional[_Union[Scoreboard.Timeline, _Mapping]] = ..., default_sort_column: _Optional[str] = ..., default_sort_order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., format: _Optional[_Union[_format_pb2.Format, str]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UploadAssetInput(_message.Message):
    __slots__ = ["data", "filename"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    def __init__(self, filename: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadAssetOutput(_message.Message):
    __slots__ = ["link"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: str
    def __init__(self, link: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/inline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/typewriter/inline.proto\x12\x11\x65olymp.typewriter\"\xdc\x04\n\x06Inline\x12.\n\x04text\x18\x01 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.TextH\x00\x12.\n\x04link\x18\x02 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.LinkH\x00\x12.\n\x04math\x18\x03 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.MathH\x00\x12.\n\x04\x63ode\x18\x04 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.CodeH\x00\x12\x36\n\x08variable\x18\x05 \x01(\x0b\x32\".eolymp.typewriter.Inline.VariableH\x00\x1aO\n\x05Style\x12\x0c\n\x04\x62old\x18\x01 \x01(\x08\x12\x0e\n\x06italic\x18\x02 \x01(\x08\x12\x11\n\tunderline\x18\x03 \x01(\x08\x12\x15\n\rstrikethrough\x18\x04 \x01(\x08\x1a\x43\n\x04Text\x12\x0b\n\x03str\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.Style\x1a@\n\x04Link\x12\x0b\n\x03url\x18\x01 \x01(\t\x12+\n\x08\x63hildren\x18\n \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\x17\n\x04Math\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1a\x17\n\x04\x43ode\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1aH\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.StyleB\x06\n\x04nodeB7Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.typewriter.inline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriter'
  _INLINE._serialized_start=54
  _INLINE._serialized_end=658
  _INLINE_STYLE._serialized_start=312
  _INLINE_STYLE._serialized_end=391
  _INLINE_TEXT._serialized_start=393
  _INLINE_TEXT._serialized_end=460
  _INLINE_LINK._serialized_start=462
  _INLINE_LINK._serialized_end=526
  _INLINE_MATH._serialized_start=528
  _INLINE_MATH._serialized_end=551
  _INLINE_CODE._serialized_start=553
  _INLINE_CODE._serialized_end=576
  _INLINE_VARIABLE._serialized_start=578
  _INLINE_VARIABLE._serialized_end=650
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AtlasClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateProblem(self, request, **kwargs):
        path = "/problems"

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateProblem",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateProblemOutput"),
            **kwargs,
        )

    def DeleteProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteProblem",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteProblemOutput"),
            **kwargs,
        )

    def ListProblems(self, request, **kwargs):
        path = "/problems"

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListProblems",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListProblemsOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeProblem",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemOutput"),
            **kwargs,
        )

    def UpdateVisibility(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/visibility"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateVisibility",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateVisibilityOutput"),
            **kwargs,
        )

    def UpdatePrivacy(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/privacy"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdatePrivacy",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdatePrivacyOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/examples"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListExamples",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListExamplesOutput"),
            **kwargs,
        )

    def UpdateVerifier(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/verifier"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateVerifier",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateVerifierOutput"),
            **kwargs,
        )

    def DescribeVerifier(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/verifier"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeVerifier",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeVerifierOutput"),
            **kwargs,
        )

    def UpdateInteractor(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/interactor"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateInteractor",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateInteractorOutput"),
            **kwargs,
        )

    def DescribeInteractor(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/interactor"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeInteractor",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeInteractorOutput"),
            **kwargs,
        )

    def CreateStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateStatement",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateStatementOutput"),
            **kwargs,
        )

    def UpdateStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.statement_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateStatement",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateStatementOutput"),
            **kwargs,
        )

    def DeleteStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.statement_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteStatement",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteStatementOutput"),
            **kwargs,
        )

    def ListStatements(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListStatements",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListStatementsOutput"),
            **kwargs,
        )

    def DescribeStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.statement_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeStatement",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeStatementOutput"),
            **kwargs,
        )

    def CreateTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateTestset",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateTestsetOutput"),
            **kwargs,
        )

    def UpdateTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateTestset",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestsetOutput"),
            **kwargs,
        )

    def DeleteTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteTestset",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteTestsetOutput"),
            **kwargs,
        )

    def ListTestsets(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListTestsets",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListTestsetsOutput"),
            **kwargs,
        )

    def DescribeTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeTestset",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestsetOutput"),
            **kwargs,
        )

    def CreateTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateTest",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateTestOutput"),
            **kwargs,
        )

    def UpdateTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateTest",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestOutput"),
            **kwargs,
        )

    def DeleteTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteTest",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteTestOutput"),
            **kwargs,
        )

    def ListTests(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListTests",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListTestsOutput"),
            **kwargs,
        )

    def DescribeTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeTest",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestOutput"),
            **kwargs,
        )

    def GrantPermission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/permissions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/GrantPermission",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.GrantPermissionOutput"),
            **kwargs,
        )

    def RevokePermission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/permissions/"+urllib.parse.quote(request.user_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.user_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/RevokePermission",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.RevokePermissionOutput"),
            **kwargs,
        )

    def ListPermissions(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/permissions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListPermissions",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListPermissionsOutput"),
            **kwargs,
        )

    def CreateCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateCodeTemplate",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateCodeTemplateOutput"),
            **kwargs,
        )

    def UpdateCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateCodeTemplate",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateCodeTemplateOutput"),
            **kwargs,
        )

    def DeleteCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteCodeTemplate",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteCodeTemplateOutput"),
            **kwargs,
        )

    def ListCodeTemplates(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListCodeTemplates",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListCodeTemplatesOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeCodeTemplate",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeCodeTemplateOutput"),
            **kwargs,
        )

    def CreateAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateAttachment",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateAttachmentOutput"),
            **kwargs,
        )

    def UpdateAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments/"+urllib.parse.quote(request.attachment_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.attachment_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateAttachment",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateAttachmentOutput"),
            **kwargs,
        )

    def DeleteAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments/"+urllib.parse.quote(request.attachment_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.attachment_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteAttachment",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteAttachmentOutput"),
            **kwargs,
        )

    def ListAttachments(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListAttachments",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListAttachmentsOutput"),
            **kwargs,
        )

    def DescribeAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments/"+urllib.parse.quote(request.attachment_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.attachment_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeAttachment",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeAttachmentOutput"),
            **kwargs,
        )

    def DescribeChange(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/changes/"+urllib.parse.quote(request.change_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.change_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeChange",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeChangeOutput"),
            **kwargs,
        )

    def ListChanges(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/changes"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListChanges",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListChangesOutput"),
            **kwargs,
        )

    def ListProblemTop(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/top"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListProblemTop",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListProblemTopOutput"),
            **kwargs,
        )

    def DescribeProblemGrading(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/grading"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeProblemGrading",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemGradingOutput"),
            **kwargs,
        )

    def CreateSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateSolution",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateSolutionOutput"),
            **kwargs,
        )

    def UpdateSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateSolution",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateSolutionOutput"),
            **kwargs,
        )

    def DeleteSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteSolution",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteSolutionOutput"),
            **kwargs,
        )

    def ListSolutions(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListSolutions",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListSolutionsOutput"),
            **kwargs,
        )

    def DescribeSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeSolution",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeSolutionOutput"),
            **kwargs,
        )

    def PublishSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)+"/publish"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/PublishSolution",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.PublishSolutionOutput"),
            **kwargs,
        )

    def UnpublishSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)+"/unpublish"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UnpublishSolution",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UnpublishSolutionOutput"),
            **kwargs,
        )

    def ApproveSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)+"/approve"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/ApproveSolution",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ApproveSolutionOutput"),
            **kwargs,
        )

    def RefuseSolution(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/solutions/"+urllib.parse.quote(request.solution_id)+"/refuse"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.solution_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/RefuseSolution",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.RefuseSolutionOutput"),
            **kwargs,
        )

    def CreateCategory(self, request, **kwargs):
        path = "/categories"

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateCategory",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateCategoryOutput"),
            **kwargs,
        )

    def UpdateCategory(self, request, **kwargs):
        path = "/categories/"+urllib.parse.quote(request.category_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.category_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UpdateCategory",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateCategoryOutput"),
            **kwargs,
        )

    def DeleteCategory(self, request, **kwargs):
        path = "/categories/"+urllib.parse.quote(request.category_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.category_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DeleteCategory",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteCategoryOutput"),
            **kwargs,
        )

    def ListCategories(self, request, **kwargs):
        path = "/categories"

        return self.transport.request(
            name="eolymp.atlas.Atlas/ListCategories",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListCategoriesOutput"),
            **kwargs,
        )

    def DescribeCategory(self, request, **kwargs):
        path = "/categories/"+urllib.parse.quote(request.category_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.category_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeCategory",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeCategoryOutput"),
            **kwargs,
        )

    def AssignCategory(self, request, **kwargs):
        path = "/categories/"+urllib.parse.quote(request.category_id)+"/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.category_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/AssignCategory",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.AssignCategoryOutput"),
            **kwargs,
        )

    def UnassignCategory(self, request, **kwargs):
        path = "/categories/"+urllib.parse.quote(request.category_id)+"/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.category_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/UnassignCategory",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UnassignCategoryOutput"),
            **kwargs,
        )

    def CreateSubmission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/submissions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/CreateSubmission",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateSubmissionOutput"),
            **kwargs,
        )

    def DescribeSubmission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/submissions/"+urllib.parse.quote(request.submission_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.submission_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeSubmission",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeSubmissionOutput"),
            **kwargs,
        )

    def RetestSubmission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/submissions/"+urllib.parse.quote(request.submission_id)+"/retest"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.submission_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/RetestSubmission",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.RetestSubmissionOutput"),
            **kwargs,
        )

    def DescribeScore(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/scores/"+urllib.parse.quote(request.user_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.user_id = ""

        return self.transport.request(
            name="eolymp.atlas.Atlas/DescribeScore",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeScoreOutput"),
            **kwargs,
        )




from eolymp.annotations import resource_pb2 as _resource_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Solution(_message.Message):
    __slots__ = ["author_id", "content", "format", "id", "locale", "moderation_comment", "moderation_status", "problem_id", "published"]
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Moderation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    APPROVED: Solution.Moderation
    AUTHOR_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DRAFT: Solution.Moderation
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HTML: Solution.Format
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MARKDOWN: Solution.Format
    MODERATION_COMMENT_FIELD_NUMBER: _ClassVar[int]
    MODERATION_STATUS_FIELD_NUMBER: _ClassVar[int]
    NONE: Solution.Format
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    PUBLISHED_FIELD_NUMBER: _ClassVar[int]
    REJECTED: Solution.Moderation
    REVIEW: Solution.Moderation
    TEX: Solution.Format
    author_id: str
    content: str
    format: Solution.Format
    id: str
    locale: str
    moderation_comment: str
    moderation_status: Solution.Moderation
    problem_id: str
    published: bool
    def __init__(self, id: _Optional[str] = ..., problem_id: _Optional[str] = ..., author_id: _Optional[str] = ..., published: bool = ..., moderation_status: _Optional[_Union[Solution.Moderation, str]] = ..., moderation_comment: _Optional[str] = ..., locale: _Optional[str] = ..., format: _Optional[_Union[Solution.Format, str]] = ..., content: _Optional[str] = ...) -> None: ...



from eolymp.workspace import project_pb2 as _project_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectCreatedEvent(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    def __init__(self, project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...

class ProjectDeletedEvent(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    def __init__(self, project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...

class ProjectUpdatedEvent(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    def __init__(self, project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class RankerClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateScoreboard(self, request, **kwargs):
        path = "/scoreboards"

        return self.transport.request(
            name="eolymp.ranker.Ranker/CreateScoreboard",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.CreateScoreboardOutput"),
            **kwargs,
        )

    def UpdateScoreboard(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/UpdateScoreboard",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.UpdateScoreboardOutput"),
            **kwargs,
        )

    def RebuildScoreboard(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/rebuild"

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/RebuildScoreboard",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.RebuildScoreboardOutput"),
            **kwargs,
        )

    def DeleteScoreboard(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/DeleteScoreboard",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.DeleteScoreboardOutput"),
            **kwargs,
        )

    def DescribeScoreboard(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/DescribeScoreboard",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.DescribeScoreboardOutput"),
            **kwargs,
        )

    def ListScoreboards(self, request, **kwargs):
        path = "/scoreboards"

        return self.transport.request(
            name="eolymp.ranker.Ranker/ListScoreboards",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardsOutput"),
            **kwargs,
        )

    def DescribeScoreboardRow(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/rows/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""
        request.member_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/DescribeScoreboardRow",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.DescribeScoreboardRowOutput"),
            **kwargs,
        )

    def ListScoreboardRows(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/rows"

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/ListScoreboardRows",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardRowsOutput"),
            **kwargs,
        )

    def AddScoreboardColumn(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/columns"

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/AddScoreboardColumn",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.AddScoreboardColumnOutput"),
            **kwargs,
        )

    def UpdateScoreboardColumn(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/columns/"+urllib.parse.quote(request.column_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""
        request.column_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/UpdateScoreboardColumn",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.UpdateScoreboardColumnOutput"),
            **kwargs,
        )

    def DeleteScoreboardColumn(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/columns/"+urllib.parse.quote(request.column_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""
        request.column_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/DeleteScoreboardColumn",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.DeleteScoreboardColumnOutput"),
            **kwargs,
        )

    def DescribeScoreboardColumn(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/columns/"+urllib.parse.quote(request.column_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""
        request.column_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/DescribeScoreboardColumn",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.DescribeScoreboardColumnOutput"),
            **kwargs,
        )

    def ListScoreboardColumns(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/columns"

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/ListScoreboardColumns",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardColumnsOutput"),
            **kwargs,
        )

    def ListActivities(self, request, **kwargs):
        path = "/scoreboards/"+urllib.parse.quote(request.scoreboard_id)+"/activities"

        # Cleanup URL parameters to avoid any ambiguity
        request.scoreboard_id = ""

        return self.transport.request(
            name="eolymp.ranker.Ranker/ListActivities",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.ranker.ListActivitiesOutput"),
            **kwargs,
        )




from eolymp.community import member_pb2 as _member_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MemberCreatedEvent(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class MemberDeletedEvent(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class MemberUpdatedEvent(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/attribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/community/attribute.proto\x12\x10\x65olymp.community\x1a!eolymp/annotations/resource.proto\"\xa1\x04\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12<\n\x0b\x64\x65scription\x18\n \x03(\x0b\x32\'.eolymp.community.Attribute.Description\x12.\n\x04type\x18\x14 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\r\n\x05index\x18\x15 \x01(\r\x12\x10\n\x08required\x18\x1f \x01(\x08\x12\x0e\n\x06hidden\x18  \x01(\x08\x12\x0e\n\x06regexp\x18\x64 \x01(\t\x12\x0b\n\x03min\x18\x65 \x01(\x05\x12\x0b\n\x03max\x18\x66 \x01(\x05\x12\x0f\n\x07\x63hoices\x18g \x03(\t\x12\x0f\n\x07\x63ountry\x18h \x01(\t\x1a\\\n\x0b\x44\x65scription\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\"}\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\n\n\x06NUMBER\x10\x03\x12\n\n\x06\x43HOICE\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\t\n\x05\x45MAIL\x10\x06\x12\x0c\n\x08\x43HECKBOX\x10\x07\x12\x0b\n\x07\x43OUNTRY\x10\x08\x12\n\n\x06REGION\x10\t:1\xb2\xe3\n-\xba\xe3\n\tattribute\xc2\xe3\n\x15\x65olymp.universe.Space\xca\xe3\n\x03keyB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.attribute_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _ATTRIBUTE._options = None
  _ATTRIBUTE._serialized_options = b'\262\343\n-\272\343\n\tattribute\302\343\n\025eolymp.universe.Space\312\343\n\003key'
  _ATTRIBUTE._serialized_start=90
  _ATTRIBUTE._serialized_end=635
  _ATTRIBUTE_DESCRIPTION._serialized_start=365
  _ATTRIBUTE_DESCRIPTION._serialized_end=457
  _ATTRIBUTE_TYPE._serialized_start=459
  _ATTRIBUTE_TYPE._serialized_end=584
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/entitlement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/judge/entitlement.proto\x12\x0c\x65olymp.judge*\xff\x02\n\x0b\x45ntitlement\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0e\x43REATE_CONTEST\x10\x01\x12\x12\n\x0eLOOKUP_CONTEST\x10\x02\x12\x12\n\x0eMANAGE_CONTEST\x10\x03\x12\x10\n\x0cVIEW_RUNTIME\x10\x04\x12\x1a\n\x16VIEW_REGISTRATION_FORM\x10\x05\x12\x14\n\x10VIEW_PARTICIPANT\x10\x06\x12\x16\n\x12MANAGE_PARTICIPANT\x10\x07\x12\x10\n\x0cVIEW_PROBLEM\x10\x08\x12\x12\n\x0eMANAGE_PROBLEM\x10\t\x12\x15\n\x11\x43REATE_SUBMISSION\x10\n\x12\x13\n\x0fVIEW_SUBMISSION\x10\x0b\x12\x15\n\x11MANAGE_SUBMISSION\x10\x0c\x12\x15\n\x11VIEW_ANNOUNCEMENT\x10\r\x12\x17\n\x13MANAGE_ANNOUNCEMENT\x10\x0e\x12\x11\n\rCREATE_TICKET\x10\x0f\x12\x0f\n\x0bVIEW_TICKET\x10\x10\x12\x11\n\rMANAGE_TICKET\x10\x11\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.entitlement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _ENTITLEMENT._serialized_start=49
  _ENTITLEMENT._serialized_end=432
# @@protoc_insertion_point(module_scope)



from eolymp.typewriter import inline_pb2 as _inline_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Block(_message.Message):
    __slots__ = ["code", "embed", "heading", "image", "layout", "list", "math", "paragraph", "table", "widget"]
    class Code(_message.Message):
        __slots__ = ["content", "lang"]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        LANG_FIELD_NUMBER: _ClassVar[int]
        content: str
        lang: str
        def __init__(self, lang: _Optional[str] = ..., content: _Optional[str] = ...) -> None: ...
    class Embed(_message.Message):
        __slots__ = ["path", "values"]
        class Value(_message.Message):
            __slots__ = ["name", "value"]
            NAME_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            name: str
            value: str
            def __init__(self, name: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        PATH_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        path: str
        values: _containers.RepeatedCompositeFieldContainer[Block.Embed.Value]
        def __init__(self, path: _Optional[str] = ..., values: _Optional[_Iterable[_Union[Block.Embed.Value, _Mapping]]] = ...) -> None: ...
    class Heading(_message.Message):
        __slots__ = ["children", "level"]
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        LEVEL_FIELD_NUMBER: _ClassVar[int]
        children: _containers.RepeatedCompositeFieldContainer[_inline_pb2.Inline]
        level: int
        def __init__(self, level: _Optional[int] = ..., children: _Optional[_Iterable[_Union[_inline_pb2.Inline, _Mapping]]] = ...) -> None: ...
    class Image(_message.Message):
        __slots__ = ["alt", "height", "src", "title", "width", "zoomable"]
        ALT_FIELD_NUMBER: _ClassVar[int]
        HEIGHT_FIELD_NUMBER: _ClassVar[int]
        SRC_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        WIDTH_FIELD_NUMBER: _ClassVar[int]
        ZOOMABLE_FIELD_NUMBER: _ClassVar[int]
        alt: str
        height: int
        src: str
        title: str
        width: int
        zoomable: bool
        def __init__(self, src: _Optional[str] = ..., alt: _Optional[str] = ..., title: _Optional[str] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., zoomable: bool = ...) -> None: ...
    class Layout(_message.Message):
        __slots__ = ["align_content", "align_items", "children", "direction", "gap", "justify_content", "justify_items", "padding"]
        class Alignment(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        class Direction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ALIGN_CONTENT_FIELD_NUMBER: _ClassVar[int]
        ALIGN_ITEMS_FIELD_NUMBER: _ClassVar[int]
        CENTER: Block.Layout.Alignment
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        COLUMN: Block.Layout.Direction
        DIRECTION_FIELD_NUMBER: _ClassVar[int]
        END: Block.Layout.Alignment
        GAP_FIELD_NUMBER: _ClassVar[int]
        JUSTIFY_CONTENT_FIELD_NUMBER: _ClassVar[int]
        JUSTIFY_ITEMS_FIELD_NUMBER: _ClassVar[int]
        PADDING_FIELD_NUMBER: _ClassVar[int]
        ROW: Block.Layout.Direction
        START: Block.Layout.Alignment
        align_content: Block.Layout.Alignment
        align_items: Block.Layout.Alignment
        children: _containers.RepeatedCompositeFieldContainer[Container]
        direction: Block.Layout.Direction
        gap: int
        justify_content: Block.Layout.Alignment
        justify_items: Block.Layout.Alignment
        padding: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, direction: _Optional[_Union[Block.Layout.Direction, str]] = ..., align_items: _Optional[_Union[Block.Layout.Alignment, str]] = ..., align_content: _Optional[_Union[Block.Layout.Alignment, str]] = ..., justify_items: _Optional[_Union[Block.Layout.Alignment, str]] = ..., justify_content: _Optional[_Union[Block.Layout.Alignment, str]] = ..., gap: _Optional[int] = ..., padding: _Optional[_Iterable[int]] = ..., children: _Optional[_Iterable[_Union[Container, _Mapping]]] = ...) -> None: ...
    class List(_message.Message):
        __slots__ = ["children", "style"]
        class Style(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        class Item(_message.Message):
            __slots__ = ["children"]
            CHILDREN_FIELD_NUMBER: _ClassVar[int]
            children: _containers.RepeatedCompositeFieldContainer[Block]
            def __init__(self, children: _Optional[_Iterable[_Union[Block, _Mapping]]] = ...) -> None: ...
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        ORDERED: Block.List.Style
        STYLE_FIELD_NUMBER: _ClassVar[int]
        UNORDERED: Block.List.Style
        children: _containers.RepeatedCompositeFieldContainer[Block.List.Item]
        style: Block.List.Style
        def __init__(self, style: _Optional[_Union[Block.List.Style, str]] = ..., children: _Optional[_Iterable[_Union[Block.List.Item, _Mapping]]] = ...) -> None: ...
    class Math(_message.Message):
        __slots__ = ["content"]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        content: str
        def __init__(self, content: _Optional[str] = ...) -> None: ...
    class Paragraph(_message.Message):
        __slots__ = ["children"]
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        children: _containers.RepeatedCompositeFieldContainer[_inline_pb2.Inline]
        def __init__(self, children: _Optional[_Iterable[_Union[_inline_pb2.Inline, _Mapping]]] = ...) -> None: ...
    class Table(_message.Message):
        __slots__ = ["children", "header"]
        class Header(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        class Cell(_message.Message):
            __slots__ = ["children"]
            CHILDREN_FIELD_NUMBER: _ClassVar[int]
            children: _containers.RepeatedCompositeFieldContainer[Block]
            def __init__(self, children: _Optional[_Iterable[_Union[Block, _Mapping]]] = ...) -> None: ...
        class Row(_message.Message):
            __slots__ = ["children"]
            CHILDREN_FIELD_NUMBER: _ClassVar[int]
            children: _containers.RepeatedCompositeFieldContainer[Block.Table.Cell]
            def __init__(self, children: _Optional[_Iterable[_Union[Block.Table.Cell, _Mapping]]] = ...) -> None: ...
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        HEADER_FIELD_NUMBER: _ClassVar[int]
        HORIZONTAL: Block.Table.Header
        VERTICAL: Block.Table.Header
        children: _containers.RepeatedCompositeFieldContainer[Block.Table.Row]
        header: Block.Table.Header
        def __init__(self, header: _Optional[_Union[Block.Table.Header, str]] = ..., children: _Optional[_Iterable[_Union[Block.Table.Row, _Mapping]]] = ...) -> None: ...
    class Widget(_message.Message):
        __slots__ = ["attributes", "children", "name"]
        class AttributesEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        attributes: _containers.ScalarMap[str, str]
        children: _containers.RepeatedCompositeFieldContainer[Block]
        name: str
        def __init__(self, name: _Optional[str] = ..., attributes: _Optional[_Mapping[str, str]] = ..., children: _Optional[_Iterable[_Union[Block, _Mapping]]] = ...) -> None: ...
    CODE_FIELD_NUMBER: _ClassVar[int]
    EMBED_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    LAYOUT_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    MATH_FIELD_NUMBER: _ClassVar[int]
    PARAGRAPH_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    WIDGET_FIELD_NUMBER: _ClassVar[int]
    code: Block.Code
    embed: Block.Embed
    heading: Block.Heading
    image: Block.Image
    layout: Block.Layout
    list: Block.List
    math: Block.Math
    paragraph: Block.Paragraph
    table: Block.Table
    widget: Block.Widget
    def __init__(self, paragraph: _Optional[_Union[Block.Paragraph, _Mapping]] = ..., layout: _Optional[_Union[Block.Layout, _Mapping]] = ..., code: _Optional[_Union[Block.Code, _Mapping]] = ..., math: _Optional[_Union[Block.Math, _Mapping]] = ..., image: _Optional[_Union[Block.Image, _Mapping]] = ..., heading: _Optional[_Union[Block.Heading, _Mapping]] = ..., list: _Optional[_Union[Block.List, _Mapping]] = ..., embed: _Optional[_Union[Block.Embed, _Mapping]] = ..., table: _Optional[_Union[Block.Table, _Mapping]] = ..., widget: _Optional[_Union[Block.Widget, _Mapping]] = ...) -> None: ...

class Container(_message.Message):
    __slots__ = ["children"]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    children: _containers.RepeatedCompositeFieldContainer[Block]
    def __init__(self, children: _Optional[_Iterable[_Union[Block, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/keeper/keeper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/keeper/keeper.proto\x12\reolymp.keeper\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"!\n\x11\x43reateObjectInput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"F\n\x12\x43reateObjectOutput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08\x62lob_ern\x18\x02 \x01(\t\x12\x11\n\tblob_hash\x18\x03 \x01(\t\"\"\n\x13\x44\x65scribeObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"$\n\x14\x44\x65scribeObjectOutput\x12\x0c\n\x04size\x18\x01 \x01(\x05\"@\n\x13\x44ownloadObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"2\n\x14\x44ownloadObjectOutput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04size\x18\x02 \x01(\x05\x32\xdc\x03\n\x06Keeper\x12\x90\x01\n\x0c\x43reateObject\x12 .eolymp.keeper.CreateObjectInput\x1a!.eolymp.keeper.CreateObjectOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\n\"\x08/objects\x12\x9b\x01\n\x0e\x44\x65scribeObject\x12\".eolymp.keeper.DescribeObjectInput\x1a#.eolymp.keeper.DescribeObjectOutput\"@\x82\xe3\n\x16\x8a\xe3\n\x12keeper:object:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x10\x12\x0e/objects/{key}\x12\xa0\x01\n\x0e\x44ownloadObject\x12\".eolymp.keeper.DownloadObjectInput\x1a#.eolymp.keeper.DownloadObjectOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12keeper:object:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x15\x12\x13/objects/{key}/dataB/Z-github.com/eolymp/go-sdk/eolymp/keeper;keeperb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.keeper.keeper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/keeper;keeper'
  _KEEPER.methods_by_name['CreateObject']._options = None
  _KEEPER.methods_by_name['CreateObject']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\014\365\342\n\000\000\000@\370\342\n\364\003\202\323\344\223\002\n\"\010/objects'
  _KEEPER.methods_by_name['DescribeObject']._options = None
  _KEEPER.methods_by_name['DescribeObject']._serialized_options = b'\202\343\n\026\212\343\n\022keeper:object:read\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\020\022\016/objects/{key}'
  _KEEPER.methods_by_name['DownloadObject']._options = None
  _KEEPER.methods_by_name['DownloadObject']._serialized_options = b'\202\343\n\026\212\343\n\022keeper:object:read\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\025\022\023/objects/{key}/data'
  _CREATEOBJECTINPUT._serialized_start=144
  _CREATEOBJECTINPUT._serialized_end=177
  _CREATEOBJECTOUTPUT._serialized_start=179
  _CREATEOBJECTOUTPUT._serialized_end=249
  _DESCRIBEOBJECTINPUT._serialized_start=251
  _DESCRIBEOBJECTINPUT._serialized_end=285
  _DESCRIBEOBJECTOUTPUT._serialized_start=287
  _DESCRIBEOBJECTOUTPUT._serialized_end=323
  _DOWNLOADOBJECTINPUT._serialized_start=325
  _DOWNLOADOBJECTINPUT._serialized_end=389
  _DOWNLOADOBJECTOUTPUT._serialized_start=391
  _DOWNLOADOBJECTOUTPUT._serialized_end=441
  _KEEPER._serialized_start=444
  _KEEPER._serialized_end=920
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class CommunityClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def JoinSpace(self, request, **kwargs):
        path = "/members/_self"

        return self.transport.request(
            name="eolymp.community.Community/JoinSpace",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.JoinSpaceOutput"),
            **kwargs,
        )

    def LeaveSpace(self, request, **kwargs):
        path = "/members/_self"

        return self.transport.request(
            name="eolymp.community.Community/LeaveSpace",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.LeaveSpaceOutput"),
            **kwargs,
        )

    def RegisterMember(self, request, **kwargs):
        path = "/members/_self/attributes"

        return self.transport.request(
            name="eolymp.community.Community/RegisterMember",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.RegisterMemberOutput"),
            **kwargs,
        )

    def IntrospectMember(self, request, **kwargs):
        path = "/members/_self"

        return self.transport.request(
            name="eolymp.community.Community/IntrospectMember",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.IntrospectMemberOutput"),
            **kwargs,
        )

    def AddMember(self, request, **kwargs):
        path = "/members"

        return self.transport.request(
            name="eolymp.community.Community/AddMember",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.AddMemberOutput"),
            **kwargs,
        )

    def UpdateMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            name="eolymp.community.Community/UpdateMember",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UpdateMemberOutput"),
            **kwargs,
        )

    def RemoveMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            name="eolymp.community.Community/RemoveMember",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.RemoveMemberOutput"),
            **kwargs,
        )

    def DescribeMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            name="eolymp.community.Community/DescribeMember",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeMemberOutput"),
            **kwargs,
        )

    def ListMembers(self, request, **kwargs):
        path = "/members"

        return self.transport.request(
            name="eolymp.community.Community/ListMembers",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.ListMembersOutput"),
            **kwargs,
        )

    def AddMemberIdentity(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)+"/identities"

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            name="eolymp.community.Community/AddMemberIdentity",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.AddMemberIdentityOutput"),
            **kwargs,
        )

    def UpdateMemberIdentity(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)+"/identities/"+urllib.parse.quote(request.identity_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""
        request.identity_id = ""

        return self.transport.request(
            name="eolymp.community.Community/UpdateMemberIdentity",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UpdateMemberIdentityOutput"),
            **kwargs,
        )

    def RemoveMemberIdentity(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)+"/identities/"+urllib.parse.quote(request.identity_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""
        request.identity_id = ""

        return self.transport.request(
            name="eolymp.community.Community/RemoveMemberIdentity",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.RemoveMemberIdentityOutput"),
            **kwargs,
        )

    def AddAttribute(self, request, **kwargs):
        path = "/attributes"

        return self.transport.request(
            name="eolymp.community.Community/AddAttribute",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.AddAttributeOutput"),
            **kwargs,
        )

    def UpdateAttribute(self, request, **kwargs):
        path = "/attributes/"+urllib.parse.quote(request.attribute_key)

        # Cleanup URL parameters to avoid any ambiguity
        request.attribute_key = ""

        return self.transport.request(
            name="eolymp.community.Community/UpdateAttribute",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UpdateAttributeOutput"),
            **kwargs,
        )

    def RemoveAttribute(self, request, **kwargs):
        path = "/attributes/"+urllib.parse.quote(request.attribute_key)

        # Cleanup URL parameters to avoid any ambiguity
        request.attribute_key = ""

        return self.transport.request(
            name="eolymp.community.Community/RemoveAttribute",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.RemoveAttributeOutput"),
            **kwargs,
        )

    def DescribeAttribute(self, request, **kwargs):
        path = "/attributes/"+urllib.parse.quote(request.attribute_key)

        # Cleanup URL parameters to avoid any ambiguity
        request.attribute_key = ""

        return self.transport.request(
            name="eolymp.community.Community/DescribeAttribute",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeAttributeOutput"),
            **kwargs,
        )

    def ListAttributes(self, request, **kwargs):
        path = "/attributes"

        return self.transport.request(
            name="eolymp.community.Community/ListAttributes",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.ListAttributesOutput"),
            **kwargs,
        )

    def DescribeIdentityProvider(self, request, **kwargs):
        path = "/idp"

        return self.transport.request(
            name="eolymp.community.Community/DescribeIdentityProvider",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeIdentityProviderOutput"),
            **kwargs,
        )

    def ConfigureIdentityProvider(self, request, **kwargs):
        path = "/idp"

        return self.transport.request(
            name="eolymp.community.Community/ConfigureIdentityProvider",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.ConfigureIdentityProviderOutput"),
            **kwargs,
        )




from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import attribute_pb2 as _attribute_pb2
from eolymp.community import idp_pb2 as _idp_pb2
from eolymp.community import member_pb2 as _member_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddAttributeInput(_message.Message):
    __slots__ = ["attribute", "attribute_key"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ..., attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class AddAttributeOutput(_message.Message):
    __slots__ = ["ern"]
    ERN_FIELD_NUMBER: _ClassVar[int]
    ern: str
    def __init__(self, ern: _Optional[str] = ...) -> None: ...

class AddMemberIdentityInput(_message.Message):
    __slots__ = ["identity", "member_id"]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    identity: _member_pb2.Member.Identity
    member_id: str
    def __init__(self, member_id: _Optional[str] = ..., identity: _Optional[_Union[_member_pb2.Member.Identity, _Mapping]] = ...) -> None: ...

class AddMemberIdentityOutput(_message.Message):
    __slots__ = ["identity_id"]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    identity_id: str
    def __init__(self, identity_id: _Optional[str] = ...) -> None: ...

class AddMemberInput(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class AddMemberOutput(_message.Message):
    __slots__ = ["ern", "member_id"]
    ERN_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    ern: str
    member_id: str
    def __init__(self, ern: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class ConfigureIdentityProviderInput(_message.Message):
    __slots__ = ["local", "oidc"]
    LOCAL_FIELD_NUMBER: _ClassVar[int]
    OIDC_FIELD_NUMBER: _ClassVar[int]
    local: bool
    oidc: _idp_pb2.IdentityProvider.OIDC
    def __init__(self, local: bool = ..., oidc: _Optional[_Union[_idp_pb2.IdentityProvider.OIDC, _Mapping]] = ...) -> None: ...

class ConfigureIdentityProviderOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeAttributeInput(_message.Message):
    __slots__ = ["attribute_key"]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ...) -> None: ...

class DescribeAttributeOutput(_message.Message):
    __slots__ = ["attribute"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    def __init__(self, attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class DescribeIdentityProviderInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeIdentityProviderOutput(_message.Message):
    __slots__ = ["local", "oidc"]
    LOCAL_FIELD_NUMBER: _ClassVar[int]
    OIDC_FIELD_NUMBER: _ClassVar[int]
    local: bool
    oidc: _idp_pb2.IdentityProvider.OIDC
    def __init__(self, local: bool = ..., oidc: _Optional[_Union[_idp_pb2.IdentityProvider.OIDC, _Mapping]] = ...) -> None: ...

class DescribeMemberInput(_message.Message):
    __slots__ = ["member_id"]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    def __init__(self, member_id: _Optional[str] = ...) -> None: ...

class DescribeMemberOutput(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class IntrospectMemberInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectMemberOutput(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class JoinSpaceInput(_message.Message):
    __slots__ = ["name", "values"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    name: str
    values: _containers.RepeatedCompositeFieldContainer[_member_pb2.Member.Value]
    def __init__(self, name: _Optional[str] = ..., values: _Optional[_Iterable[_Union[_member_pb2.Member.Value, _Mapping]]] = ...) -> None: ...

class JoinSpaceOutput(_message.Message):
    __slots__ = ["ern", "member_id"]
    ERN_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    ern: str
    member_id: str
    def __init__(self, ern: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class LeaveSpaceInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class LeaveSpaceOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListAttributesInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["hidden", "id", "key", "required", "type"]
        HIDDEN_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        REQUIRED_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        hidden: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        required: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., hidden: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., required: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListAttributesInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListAttributesInput.Filter, _Mapping]] = ...) -> None: ...

class ListAttributesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_attribute_pb2.Attribute, _Mapping]]] = ...) -> None: ...

class ListMembersInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["disabled", "id", "identity_email", "identity_name", "identity_nickname", "name", "user_id"]
        DISABLED_FIELD_NUMBER: _ClassVar[int]
        IDENTITY_EMAIL_FIELD_NUMBER: _ClassVar[int]
        IDENTITY_NAME_FIELD_NUMBER: _ClassVar[int]
        IDENTITY_NICKNAME_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        disabled: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        identity_email: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        identity_name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        identity_nickname: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        user_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., disabled: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., identity_name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., identity_nickname: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., identity_email: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListMembersInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListMembersInput.Filter, _Mapping]] = ...) -> None: ...

class ListMembersOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_member_pb2.Member]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_member_pb2.Member, _Mapping]]] = ...) -> None: ...

class RegisterMemberInput(_message.Message):
    __slots__ = ["values"]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[_member_pb2.Member.Value]
    def __init__(self, values: _Optional[_Iterable[_Union[_member_pb2.Member.Value, _Mapping]]] = ...) -> None: ...

class RegisterMemberOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RemoveAttributeInput(_message.Message):
    __slots__ = ["attribute_key"]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ...) -> None: ...

class RemoveAttributeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RemoveMemberIdentityInput(_message.Message):
    __slots__ = ["identity_id", "member_id"]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    identity_id: str
    member_id: str
    def __init__(self, member_id: _Optional[str] = ..., identity_id: _Optional[str] = ...) -> None: ...

class RemoveMemberIdentityOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RemoveMemberInput(_message.Message):
    __slots__ = ["member_id"]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    def __init__(self, member_id: _Optional[str] = ...) -> None: ...

class RemoveMemberOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateAttributeInput(_message.Message):
    __slots__ = ["attribute", "attribute_key"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ..., attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class UpdateAttributeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateMemberIdentityInput(_message.Message):
    __slots__ = ["identity", "identity_id", "member_id"]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    identity: _member_pb2.Member.Identity
    identity_id: str
    member_id: str
    def __init__(self, member_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., identity: _Optional[_Union[_member_pb2.Member.Identity, _Mapping]] = ...) -> None: ...

class UpdateMemberIdentityOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateMemberInput(_message.Message):
    __slots__ = ["member", "member_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    DISABLED: UpdateMemberInput.Patch
    GHOST: UpdateMemberInput.Patch
    IDENTITIES: UpdateMemberInput.Patch
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME: UpdateMemberInput.Patch
    OUT_OF_COMPETITION: UpdateMemberInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    REGISTERED: UpdateMemberInput.Patch
    VALUES: UpdateMemberInput.Patch
    member: _member_pb2.Member
    member_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateMemberInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateMemberInput.Patch, str]]] = ..., member_id: _Optional[str] = ..., member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class UpdateMemberOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
SERVICE_FIELD_NUMBER: _ClassVar[int]
service: _descriptor.FieldDescriptor

class Service(_message.Message):
    __slots__ = ["internal", "space"]
    INTERNAL_FIELD_NUMBER: _ClassVar[int]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    internal: bool
    space: bool
    def __init__(self, space: bool = ..., internal: bool = ...) -> None: ...
